// gpio.c
// Init GPIO ports for static I/O. Stolen from Z8 ledblink proj.

#include <eZ8.h>
int ticker = 0;
char state;

// Initializes LED ports - Port C 
// Uses high output drive. Requires resistor in series with LED, but has no switching noise.
void init_led_gpio(void)
{
  PCADDR 	= 0x01;     // PC Data Dir =
  PCCTL 	&= ~0xC0;   // PC6-PC7 as Output
  
  PCADDR 	= 0x04;     // PC high output drive =
  PCHDE 	|= 0xC0;   	// PC6-PC7 for high output
}

// This is the control algorithm status LED
// Operate LED on port C, bit 6. High is ON.
void LED_PC6( char state )
{
	if( state ) PCOUT |= 0x40;
	else PCOUT &= ~0x40;
}

// This is the "activity" LED showing that the algorithm is running.
// Operate LED on port C, bit 7. High is ON.
void LED_PC7( char state )
{
	if( state ) PCOUT |= 0x80;
	else PCOUT &= ~0x80;
}

// Blink status LED. Assumes this is called periodically, like every 0.5 sec
// state of LED will change each time interval ticks has passed.
void blink_led( int interval )
{
	if( (ticker++ % interval) == 0 ) state = ~state;
	if (state) LED_PC6(1); 
	else LED_PC6(0); 
}
